# Generated by roxygen2: do not edit by hand

export(create_codebook)
export(download_all_ces_datasets)
export(download_ces_dataset)
export(download_pdf_codebook)
export(examine_metadata)
export(export_codebook)
export(get_ces)
export(get_ces_subset)
export(list_ces_datasets)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(haven,as_factor)
importFrom(haven,read_dta)
importFrom(haven,read_sav)
importFrom(tibble,as_tibble)
importFrom(utils,download.file)
importFrom(utils,unzip)
